# Tested japanese word2vec models.

Not all the models are tested due to limited computation resources, 
but at least, I tested `cc.ja.300.json`, and one of each model provided `chive/` and `cl-tohou_jawiki_vector` in `/tests/vectorizer/test_swem_vectorizer.py.`